@@ -122,13 +122,6 @@ enum ss_cssu {
 	SS_MT_CALL_DEFLECTED =			9,
 };
 
-enum pin_type {
-	PIN_TYPE_NONE,
-	PIN_TYPE_PIN,
-	PIN_TYPE_PUK,
-	PIN_TYPE_NET,
-};
-
 /* 27.007 Section 10.1.10 */
 enum context_status {
 	CONTEXT_STATUS_DEACTIVATED = 0,
@@ -162,8 +155,6 @@ const char *ss_control_type_to_string(enum ss_control_type type);
 
 const char *bearer_class_to_string(enum bearer_class cls);
 
-gboolean is_valid_pin(const char *pin, enum pin_type type);
-
 const char *registration_status_to_string(int status);
 const char *registration_tech_to_string(int tech);
 const char *packet_bearer_to_string(int bearer);
